(
	/*
		The script is meant to change the file type loaded in VRayHDRI loader maps to .TX
		It has two modes of operation: 
		SAFE, which checks for the files' existence, but could potentially take a long time dpeneding on where the files are,
		QUICK, which simply changes the files' extension, and calls it quit. It could potentially give rise to missing file warnings, should the TX files not be present on disk.
	*/
	
	global txRepRoll 
	try (destroyDialog txRepRoll) catch ()
	
	local opMode = "quick"
	local theLoaders = #()
	local theFilePaths = #()
	
	fn getSceneLoaders = 
	(
		theLoaders = getClassInstances VRayHDRI
	)
	
	fn getFilePaths =
	(
		for l in theLoaders do append theFilePaths l.HDRIMapName
	)
	
	fn changePaths opMode =
	(
		txRepRoll.pb1.color.h=0
		case opMode of 
		(
			"quick":
			(
				
				p=0
				for l in theLoaders do
				(
					windows.processPostedMessages()
					oldName=l.HDRIMapName
					if oldName != "" and oldName != undefined do 
					(
						newName = (getfilenamepath oldName + getfilenamefile oldName + ".tx")
						l.HDRIMapName = newName
						print ("Replaced " + oldName + " with " + newName )
					)
					p+=1
					percent = (p as float / theLoaders.count)*100.0
					txRepRoll.pb1.value = percent
					newCol = txRepRoll.pb1.color
					newCol.h=96.0*percent/100.0
					txRepRoll.pb1.color =  newCol
				)
			)
			"safe":
			(
				p=0
				for l in theLoaders do
				(
					windows.processPostedMessages()
					oldName = l.HDRIMapName
					if oldName != "" and oldName != undefined do 
					(
						newName = (getfilenamepath oldName + getfilenamefile oldName + ".tx")
						try
						(
							if doesFileExist newName do 
							(
								l.HDRIMapName = newName
								print ("Replaced " + oldName + " with " + newName )
							)
						)
						catch ()
					)
					p+=1
					percent = (p as float / theLoaders.count)*100.0	
					txRepRoll.pb1.value = percent
					newCol = txRepRoll.pb1.color
					newCol.h=96.0*percent/100.0
					txRepRoll.pb1.color =  newCol					
				)
			)
		)
	)
	
	fn setOpMode =
	(
		opMode = if txRepRoll.ckb1.checked then "quick" else "safe"
	)
	
	rollout txRepRoll ".TX Replacer" width:376 height:128
	(
		checkButton 'ckb1' "Quick Replacement (No File Checks)" pos:[8,8] width:360 height:40 checked:true align:#left
		button 'btn1' "Replace!" pos:[8,56] width:360 height:40 align:#left
		progressBar 'pb1' "ProgressBar" pos:[8,104] width:360 height:16 align:#left color:(color 255 0 0)
		
		on txRepRoll open do setOpMode()
		
		on ckb1 changed state do 
		(
			setOpMode()
			ckb1.text = if state then "Quick Replacement (No File Checks)" else "Safe Replacement (File Existence Checks)"
		)
		
		on btn1 pressed do
		(
			getSceneLoaders()
			changePaths opMode
		)
	)
	
	createDialog txRepRoll
)